@@ -29,7 +29,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2017  Craig Barratt
+#   Copyright (C) 2001-2018  Craig Barratt
 #
 #   See http://backuppc.sourceforge.net.
 #
@@ -257,7 +257,7 @@ $Conf{MaxOldLogFiles} = 14;
 # Full path to the df command.  Security caution: normal users
 # should not allowed to write to this file or directory.
 #
-$Conf{DfPath} = '/usr/sbin/df';
+$Conf{DfPath} = '/usr/bin/df';
 
 #
 # Command to run df.  The following variables are substituted at run-time:
@@ -274,11 +274,11 @@ $Conf{DfCmd} = '$dfPath $topDir';
 #
 # Full path to various commands for archiving
 #
-$Conf{SplitPath} = '/usr/sbin/split';
-$Conf{ParPath}   = '/usr/sbin/par2';
-$Conf{CatPath}   = '/usr/sbin/cat';
-$Conf{GzipPath}  = '/usr/sbin/gzip';
-$Conf{Bzip2Path} = '/usr/sbin/bzip2';
+$Conf{SplitPath} = '/usr/bin/split';
+$Conf{ParPath}   = '/usr/bin/par2';
+$Conf{CatPath}   = '/usr/bin/cat';
+$Conf{GzipPath}  = '/usr/bin/gzip';
+$Conf{Bzip2Path} = '/usr/bin/bzip2';
 
 #
 # Maximum threshold for disk utilization on the __TOPDIR__ filesystem.
@@ -1130,7 +1130,7 @@ $Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
 #
 # This setting only matters if $Conf{XferMethod} = 'tar'.
 #
-$Conf{TarClientPath} = '/usr/sbin/tar';
+$Conf{TarClientPath} = '/usr/bin/tar';
 
 ###########################################################################
 # Rsync/Rsyncd Configuration
@@ -1282,6 +1282,7 @@ $Conf{RsyncArgs} = [
 #                                 $Conf{ClientNameAlias} is set)
 #        $hostIP       IP address of host
 #        $confDir      configuration directory path
+#        $shareName    share name being backed up
 #
 # This allows settings of the form:
 #
@@ -1821,6 +1822,12 @@ $Conf{UserCmdCheckStatus} = 0;
 #
 $Conf{ClientNameAlias} = undef;
 
+#
+# A user-settable comment string that is displayed in this host's status.
+# The value is otherwise ignored by BackupPC.
+#
+$Conf{ClientComment} = undef;
+
 ###########################################################################
 # Email reminders, status and messages
 # (can be overridden in the per-PC config.pl)
@@ -2196,6 +2203,7 @@ $Conf{CgiUserConfigEdit} = {
         BlackoutPeriods           => 1,
         ClientCharset             => 1,
         ClientCharsetLegacy       => 1,
+        ClientComment             => 1,
         ClientNameAlias           => 1,
         ClientTimeout             => 1,
         CompressLevel             => 1,
