@@ -1,4 +1,4 @@
-#!/usr/sbin/perl
+#!/usr/bin/perl
 #
 # By Reginaldo Ferreira <reginaldo@lepper.com.br> (23.07.2004 for V2.1.10)
 #
@@ -167,6 +167,7 @@ Existem \$hostCntGood hosts com backup, de um total de :
 <table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Usuario </td>
+    <td align="center"> Comente </td>
     <td align="center"> #Completo </td>
     <td align="center"> Completo Antig. (Dias) </td>
     <td align="center"> Completo Tamanho (GiB) </td>
@@ -313,6 +314,7 @@ EOF
 
 # --------------------------------
 $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Solicitao de Backup por \$host";
+$Lang{BackupPC__Delete_Requested_for_a_backup_of__host} = "BackupPC: Delete Requested for a backup of \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -648,6 +650,35 @@ $Lang{BackupPC_Archive_Reply_from_server} = <<EOF;
 A resposta do servidor foi: \$reply
 EOF
 
+
+# --------------------------------
+$Lang{BackupPC__Delete_Backup_Confirm__num_of__host} = "BackupPC: Delete Backup Confirm #\$num of \$host";
+# --------------------------------
+$Lang{A_filled} = "a filled";
+$Lang{An_unfilled} = "an unfilled";
+$Lang{Are_you_sure_delete} = <<EOF;
+\${h1("Are you sure?")}
+<p>
+You are about to delete \$filled \$type backup #\$num of \$host.
+
+<form name="Confirm" action="\$MyURL" method="get">
+
+<input type="hidden" name="host" value="\${EscHTML(\$host)}">
+<input type="hidden" name="num" value="\$num">
+
+<input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
+
+Do you really want to do this?
+
+<input type="button" value="\${EscHTML(\$Lang->{CfgEdit_Button_Delete})}"
+ onClick="document.Confirm.action.value='deleteBackup';
+          document.Confirm.submit();">
+
+<input type="submit" value="No" name="ignore">
+</form>
+EOF
+
 # -------------------------
 $Lang{Host__host_Backup_Summary} = "BackupPC: Host \$host Resumo do Backup";
 
@@ -685,6 +716,7 @@ Clique no nmero do Backup para revisar e restaurar arquivos.
     <td align="center"> Data Incio </td>
     <td align="center"> Durao/min </td>
     <td align="center"> Idade/dias </td>
+    <td align="center"> </td>
     <td align="center"> Rota da Cpia no Servidor </td>
 </tr>
 \$str
@@ -997,6 +1029,8 @@ $Lang{Only_privileged_users_can_view_log_files} = "Somente os usurios autorizado
 $Lang{Only_privileged_users_can_view_email_summaries} = "Somente os usurios autorizados podem ver resumos de email.";
 $Lang{Only_privileged_users_can_browse_backup_files} = "Somente os usurios autorizados podem revisar os arquivos de backup"
                 . " for host \${EscHTML(\$In{host})}.";
+$Lang{Only_privileged_users_can_delete_backups} = "Only privileged users can delete backups"
+                . " of host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Nmero de host vazio.";
 $Lang{Directory___EscHTML} = "O diretrio \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
 		    . " est vazio";
@@ -1046,6 +1080,8 @@ $Lang{Backup_requested_on__host_by__User} = "Solicitao de backup em \$host por \
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Backup parado/desprogramado em \$host por \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restaurao solicitada para o host \$hostDest, backup #\$num,"
 	     . " por \$User desde \$ENV{REMOTE_ADDR}";
+$Lang{Delete_requested_for_backup_of__host_by__User} = "Delete requested for backup #\$num of \$host"
+             . " by \$User from \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Arquivo solicitado por \$User desde \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
