@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2017  Craig Barratt
+#   Copyright (C) 2001-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 4.1.1, released 29 Mar 2017.
+# Version 4.2.0, released 8 Apr 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -97,7 +97,7 @@ sub new
 
     my $bpc = bless {
 	%$paths,
-        Version => '4.1.1',
+        Version => '4.2.0',
     }, $class;
 
     $bpc->{storage} = BackupPC::Storage->new($paths);
@@ -904,7 +904,7 @@ sub NetBiosInfoGet
     my($s, $nmbCmd);
 
     #
-    # Skip NetBios check if NmbLookupCmd is emtpy
+    # Skip NetBios check if NmbLookupCmd is empty
     #
     if ( $bpc->{Conf}{NmbLookupCmd} eq "" ) {
 	print(STDERR "NetBiosInfoGet: return $host because \$Conf{NmbLookupCmd}"
@@ -952,7 +952,7 @@ sub NetBiosHostIPFind
     my($s, $nmbCmd, $subnet, $ipAddr, $firstIpAddr);
 
     #
-    # Skip NetBios lookup if NmbLookupFindHostCmd is emtpy
+    # Skip NetBios lookup if NmbLookupFindHostCmd is empty
     #
     if ( $bpc->{Conf}{NmbLookupFindHostCmd} eq "" ) {
 	print(STDERR "NetBiosHostIPFind: return $host because"
@@ -1029,7 +1029,7 @@ sub fileNameUnmangle
 
 #
 # Escape shell meta-characters with backslashes.
-# This should be applied to each argument seperately, not an
+# This should be applied to each argument separately, not an
 # entire shell command.
 #
 sub shellEscape
@@ -1365,6 +1365,39 @@ sub sortedPCLogFiles
     return sort compareLOGName @files;
 }
 
+#
+# Opens a writeable file handle to the per-client's LOG file.
+# Also ages LOG files if the LOG file is new
+#
+sub openPCLogFile
+{
+    my($bpc, $client) = @_;
+    my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
+    my $logPath = sprintf("%s/pc/%s/LOG.%02d%04d", $bpc->{TopDir}, $client, $mon + 1, $year + 1900);
+    my $logFd;
+
+    if ( !-f $logPath ) {
+        #
+        # Compress and prune old log files
+        #
+        my $lastLog = $bpc->{Conf}{MaxOldPerPCLogFiles} - 1;
+        foreach my $file ( $bpc->sortedPCLogFiles($client) ) {
+            if ( $lastLog <= 0 ) {
+                unlink($file);
+                next;
+            }
+            $lastLog--;
+            next if ( $file =~ /\.z$/ || !$bpc->{Conf}{CompressLevel} );
+            BackupPC::XS::compressCopy($file,
+                                        "$file.z",
+                                        undef,
+                                        $bpc->{Conf}{CompressLevel}, 1);
+        }
+    }
+    open($logFd, ">>", $logPath);
+    return ($logFd, $logPath);
+}
+
 #
 # converts a glob-style pattern into a perl regular expression.
 #
@@ -1417,7 +1450,9 @@ sub getHostAddrInfo
     my($bpc, $host) = @_;
     my($err, @addrs);
     eval { ($err, @addrs) = Socket::getaddrinfo($host) };
-    return 4 if ( $@ || $err || !@addrs );
+    if ( $@ || $err || !@addrs ) {
+        return defined(gethostbyname($host)) ? 4 : undef;
+    }
     return (($addrs[0])->{'family'} == Socket::AF_INET6) ? 6 : 4;
 }
 
